@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0502';
+our $VERSION = '0.0503';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -281,23 +281,24 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0502
+version 0.0503
 
 =head1 SYNOPSIS
 
   use MIDI::Bassline::Walk;
 
   my $bassline = MIDI::Bassline::Walk->new(verbose => 1);
+  my $notes = $bassline->generate('F7b5', 8);
 
   $bassline = MIDI::Bassline::Walk->new(
+    verbose   => 1,
     guitar    => 1,
     modal     => 1,
     keycenter => 'Bb',
   );
+  $notes = $bassline->generate('F7b5', 8);
 
-  my $notes = $bassline->generate('F7b5', 8);
-  # MIDI:
-  # $score->n('qn', $_) for @$notes;
+  # $score->n('qn', $_) for @$notes; # MIDI
 
 =head1 DESCRIPTION
 
@@ -463,8 +464,12 @@ L<Data::Dumper::Compact>
 
 L<Carp>
 
+L<List::SomeUtils>
+
 L<List::Util>
 
+L<Moo>
+
 L<Music::Chord::Note>
 
 L<Music::Note>
@@ -473,11 +478,7 @@ L<Music::Scales>
 
 L<Music::VoiceGen>
 
-L<Moo>
-
-L<strictures>
-
-L<namespace::clean>
+L<Set::Array>
 
 =head1 AUTHOR
 
